---
milena/ChangeLog | 4 ++++
.../value/concept/{vectorial.hh => interval.hh} | 17 +++++++++--------
2 files changed, 13 insertions(+), 8 deletions(-)
copy milena/mln/value/concept/{vectorial.hh => interval.hh} (79%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 18fa3cb..529f1b6 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,9 @@
2012-10-04 Guillaume Lazzara <z(a)lrde.epita.fr>
+ * mln/value/concept/interval.hh: New. Add value::Interval concept.
+
+2012-10-04 Guillaume Lazzara <z(a)lrde.epita.fr>
+
Add an accumulator median based on intervals.
* mln/accu/stat/median_interval.hh,
diff --git a/milena/mln/value/concept/vectorial.hh b/milena/mln/value/concept/interval.hh
similarity index 79%
copy from milena/mln/value/concept/vectorial.hh
copy to milena/mln/value/concept/interval.hh
index b70d41f..57b1916 100644
--- a/milena/mln/value/concept/vectorial.hh
+++ b/milena/mln/value/concept/interval.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007, 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2012 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -23,12 +23,12 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_VALUE_CONCEPT_VECTORIAL_HH
-# define MLN_VALUE_CONCEPT_VECTORIAL_HH
+#ifndef MLN_VALUE_CONCEPT_INTERVAL_HH
+# define MLN_VALUE_CONCEPT_INTERVAL_HH
/*! \file
*
* \brief Define a generic class for vectorial values.
*/
# include <mln/core/concept/value.hh>
@@ -38,7 +38,7 @@ namespace mln
{
// Fwd decl.
- namespace value { template <typename E> struct Vectorial; }
+ namespace value { template <typename E> struct Interval; }
namespace trait
@@ -54,14 +54,15 @@ namespace mln
// Category flag type.
template <>
- struct Vectorial<void>
+ struct Interval<void>
{
typedef Value<void> super;
};
template <typename E>
- struct Vectorial : public Value<E>
+ struct Interval : public Value<E>
{
+ typedef Interval<void> category;
};
} // end of namespace mln::value
@@ -69,4 +70,4 @@ namespace mln
} // end of namespace mln
-#endif // ! MLN_VALUE_CONCEPT_VECTORIAL_HH
+#endif // ! MLN_VALUE_CONCEPT_INTERVAL_HH
@@ -23,12 +23,12 @@
/*! \file
*
- * \brief Define a generic class for vectorial values.
+ * \brief Define a generic class for interval of values.
*/
# include <mln/core/concept/value.hh>
--
1.7.2.5
Show replies by date